==> xlniuxdata-jinzuan-1.0.4-20150828.095541-9-sources.jar: com/xunlei/niux/data/jinzuan/vo/MemberShip.java <==
package com.xunlei.niux.data.jinzuan.vo;


import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 金钻会员信息
 * @author lisu
 * 2014-02-27
 */
@Table(tableName="jinzuan_membership",pkFieldName="seqId",pkFieldAssign=false)
public class MemberShip {

	private Long seqId;
    private Long userId;
    private Long growthValue;
    private Integer levelNum;
    private Integer memberStatus;
    private Integer isAnnualMember;
    private String registerTime;
    private String lastFeeTime;
    private String annualMemberExpireDate;
    private String memberExpireDate;
    
	@Column(columnName="registerTime",isWhereColumn=true,operator=Operator.GE)
	private String fromregisterTime;
	@Column(columnName="registerTime",isWhereColumn=true,operator=Operator.LT)
	private String toregisterTime;
    
	@Column(columnName="lastFeeTime",isWhereColumn=true,operator=Operator.GE)
	private String fromdaytime;
	@Column(columnName="lastFeeTime",isWhereColumn=true,operator=Operator.LT)
	private String todaytime;
	private Integer isPay;
    private Integer isYearPay;
    private Integer experienceStatus;
    private String lastExperienceTime;
    private String experienceDate;
    
	
	
	public Integer getExperienceStatus() {
		return experienceStatus;
	}
	public void setExperienceStatus(Integer experienceStatus) {
		this.experienceStatus = experienceStatus;
	}
	public String getLastExperienceTime() {
		return lastExperienceTime;
	}
	public void setLastExperienceTime(String lastExperienceTime) {
		this.lastExperienceTime = lastExperienceTime;
	}
	public String getExperienceDate() {
		return experienceDate;
	}
	public void setExperienceDate(String experienceDate) {
		this.experienceDate = experienceDate;
	}
	public Integer getIsYearPay() {
		return isYearPay;
	}
	public void setIsYearPay(Integer isYearPay) {
		this.isYearPay = isYearPay;
	}
	public Integer getIsPay() {
		return isPay;
	}
	public void setIsPay(Integer isPay) {
		this.isPay = isPay;
	}
	public String getFromregisterTime() {
		return fromregisterTime;
	}
	public void setFromregisterTime(String fromregisterTime) {
		this.fromregisterTime = fromregisterTime;
	}
	public String getToregisterTime() {
		return toregisterTime;
	}
	public void setToregisterTime(String toregisterTime) {
		this.toregisterTime = toregisterTime;
	}
	public String getFromdaytime() {
		return fromdaytime;
	}
	public void setFromdaytime(String fromdaytime) {
		this.fromdaytime = fromdaytime;
	}
	public String getTodaytime() {
		return todaytime;
	}
	public void setTodaytime(String todaytime) {
		this.todaytime = todaytime;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public Long getGrowthValue() {
		return growthValue;
	}
	public void setGrowthValue(Long growthValue) {
		this.growthValue = growthValue;
	}
	public Integer getLevelNum() {
		return levelNum;
	}
	public void setLevelNum(Integer levelNum) {
		this.levelNum = levelNum;
	}
	public Integer getMemberStatus() {
		return memberStatus;
	}
	public void setMemberStatus(Integer memberStatus) {
		this.memberStatus = memberStatus;
	}
	public Integer getIsAnnualMember() {
		return isAnnualMember;
	}
	public void setIsAnnualMember(Integer isAnnualMember) {
		this.isAnnualMember = isAnnualMember;
	}
	public String getRegisterTime() {
		return registerTime;
	}
	public void setRegisterTime(String registerTime) {
		this.registerTime = registerTime;
	}
	public String getLastFeeTime() {
		return lastFeeTime;
	}
	public void setLastFeeTime(String lastFeeTime) {
		this.lastFeeTime = lastFeeTime;
	}
	public String getAnnualMemberExpireDate() {
		return annualMemberExpireDate;
	}
	public void setAnnualMemberExpireDate(String annualMemberExpireDate) {
		this.annualMemberExpireDate = annualMemberExpireDate;
	}
	public String getMemberExpireDate() {
		return memberExpireDate;
	}
	public void setMemberExpireDate(String memberExpireDate) {
		this.memberExpireDate = memberExpireDate;
	}
    
}

==> xlniuxdata-jinzuan-1.0.5-20151102.060947-7-sources.jar: com/xunlei/niux/data/jinzuan/vo/MemberShip.java <==
package com.xunlei.niux.data.jinzuan.vo;


import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 金钻会员信息
 * @author lisu
 * 2014-02-27
 */
@Table(tableName="jinzuan_membership",pkFieldName="seqId",pkFieldAssign=false)
public class MemberShip {

	private Long seqId;
    private Long userId;
    private Long growthValue;
    private Integer levelNum;
    private Integer memberStatus;
    private Integer isAnnualMember;
    private String registerTime;
    private String lastFeeTime;
    private String annualMemberExpireDate;
    private String memberExpireDate;
    
	@Column(columnName="registerTime",isWhereColumn=true,operator=Operator.GE)
	private String fromregisterTime;
	@Column(columnName="registerTime",isWhereColumn=true,operator=Operator.LT)
	private String toregisterTime;
    
	@Column(columnName="lastFeeTime",isWhereColumn=true,operator=Operator.GE)
	private String fromdaytime;
	@Column(columnName="lastFeeTime",isWhereColumn=true,operator=Operator.LT)
	private String todaytime;
	private Integer isPay;
    private Integer isYearPay;
    private Integer experienceStatus;
    private String lastExperienceTime;
    private String experienceDate;
    private Integer duobaoStatus;
    private String lastDuobaoTime;
    private String duobaoExpireDate;
    
	
	
	public Integer getDuobaoStatus() {
		return duobaoStatus;
	}
	public void setDuobaoStatus(Integer duobaoStatus) {
		this.duobaoStatus = duobaoStatus;
	}
	public String getLastDuobaoTime() {
		return lastDuobaoTime;
	}
	public void setLastDuobaoTime(String lastDuobaoTime) {
		this.lastDuobaoTime = lastDuobaoTime;
	}
	public String getDuobaoExpireDate() {
		return duobaoExpireDate;
	}
	public void setDuobaoExpireDate(String duobaoExpireDate) {
		this.duobaoExpireDate = duobaoExpireDate;
	}
	public Integer getExperienceStatus() {
		return experienceStatus;
	}
	public void setExperienceStatus(Integer experienceStatus) {
		this.experienceStatus = experienceStatus;
	}
	public String getLastExperienceTime() {
		return lastExperienceTime;
	}
	public void setLastExperienceTime(String lastExperienceTime) {
		this.lastExperienceTime = lastExperienceTime;
	}
	public String getExperienceDate() {
		return experienceDate;
	}
	public void setExperienceDate(String experienceDate) {
		this.experienceDate = experienceDate;
	}
	public Integer getIsYearPay() {
		return isYearPay;
	}
	public void setIsYearPay(Integer isYearPay) {
		this.isYearPay = isYearPay;
	}
	public Integer getIsPay() {
		return isPay;
	}
	public void setIsPay(Integer isPay) {
		this.isPay = isPay;
	}
	public String getFromregisterTime() {
		return fromregisterTime;
	}
	public void setFromregisterTime(String fromregisterTime) {
		this.fromregisterTime = fromregisterTime;
	}
	public String getToregisterTime() {
		return toregisterTime;
	}
	public void setToregisterTime(String toregisterTime) {
		this.toregisterTime = toregisterTime;
	}
	public String getFromdaytime() {
		return fromdaytime;
	}
	public void setFromdaytime(String fromdaytime) {
		this.fromdaytime = fromdaytime;
	}
	public String getTodaytime() {
		return todaytime;
	}
	public void setTodaytime(String todaytime) {
		this.todaytime = todaytime;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public Long getGrowthValue() {
		return growthValue;
	}
	public void setGrowthValue(Long growthValue) {
		this.growthValue = growthValue;
	}
	public Integer getLevelNum() {
		return levelNum;
	}
	public void setLevelNum(Integer levelNum) {
		this.levelNum = levelNum;
	}
	public Integer getMemberStatus() {
		return memberStatus;
	}
	public void setMemberStatus(Integer memberStatus) {
		this.memberStatus = memberStatus;
	}
	public Integer getIsAnnualMember() {
		return isAnnualMember;
	}
	public void setIsAnnualMember(Integer isAnnualMember) {
		this.isAnnualMember = isAnnualMember;
	}
	public String getRegisterTime() {
		return registerTime;
	}
	public void setRegisterTime(String registerTime) {
		this.registerTime = registerTime;
	}
	public String getLastFeeTime() {
		return lastFeeTime;
	}
	public void setLastFeeTime(String lastFeeTime) {
		this.lastFeeTime = lastFeeTime;
	}
	public String getAnnualMemberExpireDate() {
		return annualMemberExpireDate;
	}
	public void setAnnualMemberExpireDate(String annualMemberExpireDate) {
		this.annualMemberExpireDate = annualMemberExpireDate;
	}
	public String getMemberExpireDate() {
		return memberExpireDate;
	}
	public void setMemberExpireDate(String memberExpireDate) {
		this.memberExpireDate = memberExpireDate;
	}
    
}
